@@ -332,6 +332,7 @@ def create_new_project(session):
                 },
             )
             for task_type in [t["task_type"] for t in moving_image_template["items"]]:
+                print(task_type)
                 task = session.create(
                     "Task",
                     {
@@ -343,7 +344,7 @@ def create_new_project(session):
                 )
                 session.create(
                     "Appointment",
-                    {"context": task, "resource": moving_image_shot, "type": "assignment"},
+                    {"context": task, "resource": movingImage_artist, "type": "assignment"},
                 )
 
     # using a set here to make sure users aren't added multiple times
